import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';
import { AuthGuard } from './auth.guard';
import { LayoutComponent } from './components/layout/layout.component';
import { DashboardComponent } from './components/dashboard/dashboard.component';
import { ImageUploadComponent } from './components/image-upload/image-upload.component';
import { MembersComponent } from './components/members/members.component';
import { SiteInfoComponent } from './components/site-info/site-info.component';
import { UsersComponent } from './components/users/users.component';
import { CounsellorComponent } from './components/users/counsellor/counsellor.component';
import { ManagerComponent } from './components/users/manager/manager.component';
import { LandingPageComponent } from './components/landing-page/landing-page.component';
import { AdminComponent } from './components/users/admin/admin.component';
import { MemberDetailComponent } from './components/members/member-detail/member-detail.component';
import { SeoInfoComponent } from './components/seo-info/seo-info.component';
import { AdminDetailComponent } from './components/users/admin-detail/admin-detail.component';
import { CounsDetailComponent } from './components/users/couns-detail/couns-detail.component';
import { ManagerDetailComponent } from './components/users/manager-detail/manager-detail.component';
import { Page404Component } from './components/pages/page404/page404.component';
import { LoginComponent } from './components/login/login.component';


const routes: Routes = [
  {
    path: 'login',
    component: LoginComponent
  },
  {
    path: '',
    component: LayoutComponent,
    canActivate: [AuthGuard],
    children:
    [ {
      path: '',
      component: DashboardComponent,
      canActivate: [AuthGuard],
      },
      {
        path: 'dashboard',
        component: DashboardComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'image-upload',
        component: ImageUploadComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'site-info',
        component: SiteInfoComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'seo',
        component: SeoInfoComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'member-detail/:id',
        component: MemberDetailComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'members',
        component: MembersComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'admin-detail/:id',
        component: AdminDetailComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'couns-detail/:id',
        component: CounsDetailComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'manager-detail/:id',
        component: ManagerDetailComponent,
        canActivate: [AuthGuard],
      },
      {
        path: 'users',
        component: UsersComponent,
        canActivate: [AuthGuard],
        children: [
          {
            path: '',
            component: AdminComponent,
            canActivate: [AuthGuard],
          },
          {
            path: 'counsellor',
            component: CounsellorComponent,
            canActivate: [AuthGuard],
          },
          {
            path: 'manager',
            component: ManagerComponent,
            canActivate: [AuthGuard],
          },
          {
            path: 'admin',
            component: AdminComponent,
            canActivate: [AuthGuard],
          },
        ]
      }
    ]
  },
  {
    path: '**',
    component: Page404Component
  }

];

@NgModule({
  imports: [RouterModule.forRoot(routes, {useHash: true})],
  exports: [RouterModule]
})
export class AppRoutingModule { }
