import { Component, OnInit } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import {DashboardService} from '../../services/dashboard.service';
import { takeWhile } from 'rxjs/operators';
import { TokenService } from 'src/app/services/token.service';
import { AnimationService } from 'src/app/services/animation.service';

@Component({
  selector: 'app-dashboard',
  templateUrl: './dashboard.component.html',
  styleUrls: ['./dashboard.component.css']
})
export class DashboardComponent implements OnInit {

  private alive = true;
  memberCountValue: any;
  officeCountValue: any;
  leadsCountValue: any;
  oldLeadsCountValue: any;
  adminCountValue: any;
  counsCountValue: any;
  managerCountValue: any;
  authToken: any;

  constructor(
    private dashService: DashboardService,
    private http: HttpClient,
    private token: TokenService,
  ) { }

  ngOnInit() {
    this.membersCount();
    this.officesCount();
    this.leadsCount();
    this.oldLeadsCount();
    this.adminsCount();
    this.counsellorsCount();
    this.managersCount();
  }

  membersCount() {
    this.dashService.getMembersCount().subscribe((resp: any) => {
      this.memberCountValue = resp.member;
    },
    err => {
      console.log(err);
      return false;
    });
  }

  officesCount() {
    this.dashService.getOfficesCount().subscribe((resp: any) => {
      this.officeCountValue = resp.office;
    },
    err => {
      console.log(err);
      return false;
    });
  }

  leadsCount() {
    this.dashService.getLeadsCount().subscribe((resp: any) => {
      this.leadsCountValue = resp.lead;
    },
    err => {
      console.log(err);
      return false;
    });
  }

  oldLeadsCount() {
    this.dashService.getOldLeadsCount().subscribe((resp: any) => {
      this.oldLeadsCountValue = resp.lead;
    },
    err => {
      console.log(err);
      return false;
    });
  }

  adminsCount() {
    this.http
      .get(`${environment.url}/user/getAdmins`, {headers: this.loadToken()})
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
          // this.admins = resp.admins;
          this.adminCountValue = resp.admins.length;
          console.log( 'Admin Count: ' + this.adminCountValue);
        },
        err => {
          // console.log(err);
        }
      );
  }

  counsellorsCount() {
    this.http
      .get(`${environment.url}/user/getCounsellors`, {headers: this.loadToken()})
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
         this.counsCountValue = resp.counsellors.length;
         console.log( 'Counsellor Count: ' + this.counsCountValue);
        },
        err => {
          // console.log(err);
        }
      );
  }

  managersCount() {
    this.http
      .get(`${environment.url}/user/getManagers`, {headers: this.loadToken()})
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          // console.log(resp);
          this.managerCountValue = resp.managers.length;
          console.log( 'Manager Count: ' + this.managerCountValue);
        },
        err => {
          // console.log(err)
        }
      );
  }


  loadToken() {
    this.authToken = this.token.getToken();
    const header: HttpHeaders = new HttpHeaders().set('Authorization', this.authToken);
    return header;
  }

}
