import { Component, OnInit, OnDestroy } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { takeWhile } from 'rxjs/operators';
import { Ng2SmartTableModule, LocalDataSource } from 'ng2-smart-table';
import { TokenService } from 'src/app/services/token.service';
import { AnimationService } from 'src/app/services/animation.service';
import { Router } from '@angular/router';

@Component({
  selector: 'app-members',
  templateUrl: './members.component.html',
  styleUrls: ['./members.component.css']
})

export class MembersComponent implements OnInit, OnDestroy {
  private alive = true;
  authToken: any;
  members: any;
  memberid: any;
  filterdata: any =  {name: ''};

  constructor(
    private http: HttpClient,
    private token: TokenService,
    private as: AnimationService,
    private router: Router
  ) { }

  ngOnInit() {
    this.getMembers();
    this.as.hide();
  }

  getMembers() {
    this.authToken = this.token.getToken();
    const header: HttpHeaders = new HttpHeaders().set('Authorization', this.authToken);
    this.http
      .get(`${environment.url}/members/getAllMembers`, {headers : header})
      .pipe(takeWhile(() => this.alive))
      .subscribe(
        (resp: any) => {
          console.log(resp);
          this.members = resp.members;
        },
        err => {
          console.log(err);
        }
      );
  }

  onMemberRowSelect(event: any) {
    // console.log(event.data);
    this.memberid = event._id;
    // console.log(this.memberid);
    this.router.navigate([`member-detail/${this.memberid}`]);
  }

  ngOnDestroy() {
    this.alive = false;
    this.as.show();
  }
}




